SELECT '0'::roman;
SELECT '1'::roman;
SELECT '-2'::roman;

SELECT 'nulla'::roman;
SELECT 'minus nulla'::roman;

SELECT 'I'::roman, 'i'::roman;
SELECT 'V'::roman, 'v'::roman;
SELECT 'X'::roman, 'x'::roman;
SELECT 'L'::roman, 'l'::roman;
SELECT 'C'::roman, 'c'::roman;
SELECT 'D'::roman, 'd'::roman;
SELECT 'M'::roman, 'm'::roman;

SELECT 'minus I'::roman;
SELECT 'minus 1'::roman;

SELECT 'II'::roman;
SELECT 'III'::roman;
SELECT 'IV'::roman;
SELECT 'V'::roman;
SELECT 'VI'::roman;
SELECT 'IX'::roman;
SELECT 'XI'::roman;
SELECT 'XX'::roman;
SELECT 'IL'::roman;
SELECT 'LI'::roman;
SELECT 'VL'::roman;
SELECT 'LV'::roman;
SELECT 'XL'::roman;
SELECT 'LX'::roman;
SELECT 'XC'::roman;
SELECT 'CX'::roman;
SELECT 'CC'::roman;
SELECT 'CD'::roman;
SELECT 'DC'::roman;
SELECT 'CM'::roman;
SELECT 'MC'::roman;
SELECT 'MM'::roman;

SELECT '10000'::roman;
SELECT '-10000'::roman;
SELECT '10001'::roman;
SELECT '-10001'::roman;
