SELECT '0'::zahl;
SELECT '1'::zahl;
SELECT '-2'::zahl;

SELECT 'null'::zahl;

SELECT 'eins'::zahl;
SELECT 'minus eins'::zahl;
SELECT 'zwei'::zahl;
SELECT 'drei'::zahl;
SELECT 'vier'::zahl;
SELECT 'fünf'::zahl;
SELECT 'sechs'::zahl;
SELECT 'sieben'::zahl;
SELECT 'acht'::zahl;
SELECT 'neun'::zahl;
SELECT 'zehn'::zahl;

SELECT 'elf'::zahl;
SELECT 'zwölf'::zahl;
SELECT 'dreizehn'::zahl;
SELECT 'vierzehn'::zahl;
SELECT 'fünfzehn'::zahl;
SELECT 'sechzehn'::zahl;
SELECT 'siebzehn'::zahl;
SELECT 'achtzehn'::zahl;
SELECT 'neunzehn'::zahl;

SELECT 'zwanzig'::zahl;
SELECT 'einundzwanzig'::zahl;
SELECT 'dreißig'::zahl;
SELECT 'zweiunddreißig'::zahl;
SELECT 'vierzig'::zahl;
SELECT 'fünfzig'::zahl;
SELECT 'sechzig'::zahl;
SELECT 'siebzig'::zahl;
SELECT 'achtzig'::zahl;
SELECT 'neunzig'::zahl;

SELECT 'hundert'::zahl;
SELECT 'einhundert'::zahl;
SELECT 'hunderteins'::zahl;
SELECT 'einhunderteins'::zahl;
SELECT 'einhunderteinundzwanzig'::zahl;

SELECT 'zweihundert'::zahl;
SELECT 'zweihunderteins'::zahl;
SELECT 'zweihundertzweiunddreißig'::zahl;

SELECT 'tausend'::zahl;
SELECT 'eintausend'::zahl;
SELECT 'eintausendeins'::zahl;
SELECT 'tausendeinhundert'::zahl;
SELECT 'eintausendeinhundert'::zahl;
SELECT 'elfhundert'::zahl;
SELECT 'eintausendeinhunderteins'::zahl;

SELECT 'hunderttausend'::zahl;
SELECT 'einhunderttausend'::zahl;
SELECT 'einhunderteintausend'::zahl;
SELECT 'zweihunderttausend'::zahl;

SELECT 'eine Million'::zahl;
SELECT 'eine Million eins'::zahl;
SELECT 'eine Million einhundert'::zahl;
SELECT 'eine Million eintausend'::zahl;
SELECT 'eine Million einhunderttausend'::zahl;
SELECT 'zwei Millionen'::zahl;

SELECT 'hundert Millionen'::zahl;

SELECT 'eine Milliarde'::zahl;
SELECT 'eine Milliarde eine Million'::zahl;
SELECT 'eine Milliarde eine Million eintausend'::zahl;

SELECT 'Billion'::zahl;
SELECT 'Billiarde'::zahl;
SELECT 'Trillion'::zahl;
