SELECT '0'::numeral;
SELECT '1'::numeral;
SELECT '-2'::numeral;

SELECT 'zero'::numeral;

SELECT 'one'::numeral;
SELECT 'minus one'::numeral;
SELECT 'two'::numeral;
SELECT 'three'::numeral;
SELECT 'four'::numeral;
SELECT 'five'::numeral;
SELECT 'six'::numeral;
SELECT 'seven'::numeral;
SELECT 'eight'::numeral;
SELECT 'nine'::numeral;
SELECT 'ten'::numeral;

SELECT 'eleven'::numeral;
SELECT 'twelve'::numeral;
SELECT 'thirteen'::numeral;
SELECT 'fourteen'::numeral;
SELECT 'fifteen'::numeral;
SELECT 'sixteen'::numeral;
SELECT 'seventeen'::numeral;
SELECT 'eighteen'::numeral;
SELECT 'nineteen'::numeral;

SELECT 'twenty'::numeral;
SELECT 'twenty-one'::numeral;
SELECT 'thirty'::numeral;
SELECT 'thirty-two'::numeral;
SELECT 'forty'::numeral;
SELECT 'fifty'::numeral;
SELECT 'sixty'::numeral;
SELECT 'seventy'::numeral;
SELECT 'eighty'::numeral;
SELECT 'ninety'::numeral;

SELECT 'hundred'::numeral;
SELECT 'one hundred'::numeral;
SELECT 'hundred one'::numeral;
SELECT 'one hundred one'::numeral;
SELECT 'one hundred twenty-one'::numeral;

SELECT 'two hundred'::numeral;
SELECT 'two hundred one'::numeral;
SELECT 'two hundred thirty-two'::numeral;

SELECT 'thousand'::numeral;
SELECT 'one thousand'::numeral;
SELECT 'one thousand one'::numeral;
SELECT 'thousand one hundred'::numeral;
SELECT 'one thousand one hundred'::numeral;
SELECT 'eleven hundred'::numeral;
SELECT 'one thousand one hundred one'::numeral;

SELECT 'hundred thousand'::numeral;
SELECT 'one hundred thousand'::numeral;
SELECT 'one hundred one thousand'::numeral;
SELECT 'two hundred thousand'::numeral;

SELECT 'one million'::numeral;
SELECT 'one million one'::numeral;
SELECT 'one million one hundred'::numeral;
SELECT 'one million one thousand'::numeral;
SELECT 'one million one hundred thousand'::numeral;
SELECT 'two million'::numeral;

SELECT 'hundred million'::numeral;

SELECT 'one billion'::numeral;
SELECT 'one billion one million'::numeral;
SELECT 'one billion one million one thousand'::numeral;

SELECT 'billion'::numeral;
SELECT 'trillion'::numeral;
SELECT 'quadrillion'::numeral;
SELECT 'quintillion'::numeral;
